import { Fragment, jsx, jsxs } from "react/jsx-runtime";
import {
  Description,
  DescriptionWrapper,
  HoverMsg,
  UploaderWrapper
} from "./style";
import { acceptedExt, checkType, getFileSizeMB } from "./utils";
import { useEffect, useRef, useState } from "react";
import DrawTypes from "./DrawTypes";
import ImageAdd from "./ImageAdd";
import useDragging from "./useDragging";
const drawDescription = (currFile, uploaded, typeError, disabled, label) => {
  return typeError ? /* @__PURE__ */ jsx("span", {
    children: "File type/size error, Hovered on types!"
  }) : /* @__PURE__ */ jsx(Description, {
    children: disabled ? /* @__PURE__ */ jsx("span", {
      children: "Upload disabled"
    }) : !currFile && !uploaded ? /* @__PURE__ */ jsx(Fragment, {
      children: label ? /* @__PURE__ */ jsxs(Fragment, {
        children: [
          /* @__PURE__ */ jsx("span", {
            children: label.split(" ")[0]
          }),
          " ",
          label.substr(label.indexOf(" ") + 1)
        ]
      }) : /* @__PURE__ */ jsxs(Fragment, {
        children: [
          /* @__PURE__ */ jsx("span", {
            children: "Upload"
          }),
          " or drop a file right here"
        ]
      })
    }) : /* @__PURE__ */ jsxs(Fragment, {
      children: [
        /* @__PURE__ */ jsx("span", {
          children: "Uploaded Successfully!."
        }),
        " Upload another?"
      ]
    })
  });
};
const FileUploader = (props) => {
  const {
    name,
    hoverTitle,
    types,
    handleChange,
    classes,
    children,
    maxSize,
    minSize,
    fileOrFiles,
    onSizeError,
    onTypeError,
    onSelect,
    onDrop,
    disabled,
    label,
    multiple,
    onDraggingStateChange
  } = props;
  const labelRef = useRef(null);
  const inputRef = useRef(null);
  const [uploaded, setUploaded] = useState(false);
  const [currFiles, setFile] = useState(null);
  const [error, setError] = useState(false);
  const validateFile = (file) => {
    if (types && !checkType(file, types)) {
      setError(true);
      if (onTypeError)
        onTypeError("File type is not supported");
      return false;
    }
    if (maxSize && getFileSizeMB(file.size) > maxSize) {
      setError(true);
      if (onSizeError)
        onSizeError("File size is too big");
      return false;
    }
    if (minSize && getFileSizeMB(file.size) < minSize) {
      setError(true);
      if (onSizeError)
        onSizeError("File size is too small");
      return false;
    }
    return true;
  };
  const handleChanges = (files) => {
    let checkError = false;
    if (files) {
      if (files instanceof File) {
        checkError = !validateFile(files);
      } else {
        for (let i = 0; i < files.length; i++) {
          const file = files[i];
          checkError = !validateFile(file) || checkError;
        }
      }
      if (checkError)
        return false;
      if (handleChange)
        handleChange(files);
      setFile(files);
      setUploaded(true);
      setError(false);
      return true;
    }
    return false;
  };
  const blockEvent = (ev) => {
    ev.preventDefault();
    ev.stopPropagation();
  };
  const handleClick = (ev) => {
    ev.stopPropagation();
    if (inputRef && inputRef.current) {
      inputRef.current.click();
    }
  };
  const handleInputChange = (ev) => {
    const allFiles = ev.target.files;
    const files = multiple ? allFiles : allFiles[0];
    const success = handleChanges(files);
    if (onSelect && success)
      onSelect(files);
  };
  const dragging = useDragging({
    labelRef,
    inputRef,
    multiple,
    handleChanges,
    onDrop
  });
  useEffect(() => {
    onDraggingStateChange == null ? void 0 : onDraggingStateChange(dragging);
  }, [dragging]);
  useEffect(() => {
    if (fileOrFiles) {
      setUploaded(true);
      setFile(fileOrFiles);
    } else {
      if (inputRef.current)
        inputRef.current.value = "";
      setUploaded(false);
      setFile(null);
    }
  }, [fileOrFiles]);
  return /* @__PURE__ */ jsxs(UploaderWrapper, {
    overRide: children,
    className: `${classes || ""} ${disabled ? "is-disabled" : ""}`,
    ref: labelRef,
    htmlFor: name,
    onClick: blockEvent,
    children: [
      /* @__PURE__ */ jsx("input", {
        onClick: handleClick,
        onChange: handleInputChange,
        accept: acceptedExt(types),
        ref: inputRef,
        type: "file",
        name,
        disabled,
        multiple
      }),
      dragging && /* @__PURE__ */ jsx(HoverMsg, {
        children: /* @__PURE__ */ jsx("span", {
          children: hoverTitle || "Drop Here"
        })
      }),
      !children && /* @__PURE__ */ jsxs(Fragment, {
        children: [
          /* @__PURE__ */ jsx(ImageAdd, {}),
          /* @__PURE__ */ jsxs(DescriptionWrapper, {
            error,
            children: [
              drawDescription(currFiles, uploaded, error, disabled, label),
              /* @__PURE__ */ jsx(DrawTypes, {
                types,
                minSize,
                maxSize
              })
            ]
          })
        ]
      }),
      children
    ]
  });
};
var FileUploader_default = FileUploader;
export {
  FileUploader_default as default
};
//# sourceMappingURL=FileUploader.js.map
